==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Origin</source>
        <translation>Alkuperä</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Näytä suuret alkuperäiset akselit</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rulers and Scrollbars</source>
        <translation>Viivaimet ja vierityspalkit</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Näytä viivaimet</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Näytä vierityspalkit</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Kohdistin</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Näytä ristikko</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Näytä suuri ristikko</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>Automaattinen mittakaava/zoomaus</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Marginaali (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Värien säätö</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Estä valkoinen valkoisella / musta mustalla näytössä</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Värivaaleuden kynnys:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Viivatyypit</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Automaattisesti vaihda kuvaruudun viivat muotoilunäkymässä</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Venytä viivatyypin kuvioita viivan paksuuden mukaan</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Kuvion mitta viivapaksuudella 0.00m:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Näyttötila ja suorituskyky</translation>
    </message>
    <message>
        <location line="+332"/>
        <source>Use full resolution for Retina display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-411"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Automaattisesti käytä kuvaruudun viivoja muotoilunäkymässä</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="vanished">Vaihda viivatyyppejä automaattisesti</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Suorituskyky</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number of preview entities:</source>
        <translation>Esikatseltavien kohteiden määrä:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Tekstin korkeuden kynnysarvo näytöllä (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Näytä kaaret viivoina alle tämänmittaisen kulman (astetta):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+82"/>
        <source>Timeout for hatch rendering:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+76"/>
        <source>Maximum number of reference points displayed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+70"/>
        <source>Selection</source>
        <translation>Valinta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Pysyvä valinta</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Kuvanäkymä</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Ulkoasu</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Origin</source>
        <translation>Alkuperä</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Näytä suuret alkuperäiset akselit</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rulers and Scrollbars</source>
        <translation>Viivaimet ja vierityspalkit</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Näytä viivaimet</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Näytä vierityspalkit</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Kohdistin</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Näytä ristikko</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Näytä suuri ristikko</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>Automaattinen mittakaava/zoomaus</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Marginaali (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Värien säätö</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Estä valkoinen valkoisella / musta mustalla näytössä</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Color lightness threshold:</source>
        <translation>Värivaaleuden kynnys:</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Disable for printing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Linetypes</source>
        <translation>Viivatyypit</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Automaattisesti vaihda kuvaruudun viivat muotoilunäkymässä</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Venytä viivatyypin kuvioita viivan paksuuden mukaan</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Kuvion mitta viivapaksuudella 0.00m:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Näyttötila ja suorituskyky</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use full resolution for Retina display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Anti-aliasing on by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-78"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Automaattisesti käytä kuvaruudun viivoja muotoilunäkymässä</translation>
    </message>
    <message>
        <source>Auto switch linetypes</source>
        <translation type="vanished">Vaihda viivatyyppejä automaattisesti</translation>
    </message>
    <message>
        <source>Performance</source>
        <translation type="vanished">Suorituskyky</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Number of preview entities:</source>
        <translation>Esikatseltavien kohteiden määrä:</translation>
    </message>
    <message>
        <source>Text height display threshold (px):</source>
        <translation type="vanished">Tekstin korkeuden kynnysarvo näytöllä (px):</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Näytä kaaret viivoina alle tämänmittaisen kulman (astetta):</translation>
    </message>
    <message>
        <location line="+151"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-82"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Timeout for hatch rendering:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Maximum number of reference points displayed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Selection</source>
        <translation>Valinta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Pysyvä valinta</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Kuvanäkymä</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Ulkoasu</translation>
    </message>
</context>
</TS>
